@@ -8,13 +8,13 @@ require Exporter;
 
 use Term::ANSIColor qw(:constants);
 
+warn "Loading module - Trans_syl_seg ...\n";
+
 my $statistics="/usr/share/sylseg_sk/sylseg-sk.stats";
 my (%g1_tp, %g1_bp, %g1_mp);
 my @syl;
-my $prior=$main::prior;
-my $color=$main::color;
-
-mess("Loading module - Trans_syl_seg ...",1);
+my $prior=1;
+my $colour=0;
 
 mess("Reading statistics ...",1);
 read_statistics();
@@ -34,13 +34,14 @@ sub calc_probs
    my $w2=$seq[$i-1]; 
    my $w1=$seq[$i-2];
    $P*=b_prob("","",$w3) if($i==0);
-   $P*=b_prob("","$w2-$w3",$w3) if($i==1);
-   $P*=b_prob("$w1-$w2-$w3","$w2-$w3",$w3) if($i>1);
+   $P*=b_prob("","$w3-$w2",$w3) if($i==1);
+   $P*=b_prob("$w3-$w2-$w1","$w3-$w2",$w3) if($i>1);
   }
   mess("Prob.: $P ...",2);
   $oprb[@oprb]="${P}::$att";
  }
  return sort byval @oprb;
+ #return @oprb;
 }
 
 sub byval
@@ -161,7 +162,7 @@ sub set_debug_level
    my $tmpC=shift;
    return "Error - debug level out of range" if($tmp<0 or $tmp>5);
    $prior=$tmp;
-   $color=$tmpC if($tmpC==0 or $tmpC==1);
+   $colour=$tmpC if($tmpC==0 or $tmpC==1);
    return "true";
 }
 
@@ -172,13 +173,13 @@ sub mess
       {
         $nt=$pr-1; $ss="";
 	for($x=0;$x<$nt;$x++){$ss.="\t";}
-	print "$ss$msg \n" if($color==0);
+	print "$ss$msg \n" if($colour==0);
         #1-YELLOW,BOLD,2-YELLOW,3-GREEN,         5-default
-        print YELLOW,BOLD,"$msg \n",RESET if($pr==1 and $color==1);
-        print YELLOW,"$ss$msg \n",RESET if($pr==2 and $color==1);
-        print GREEN,"$ss$msg \n",RESET if($pr==3 and $color==1);
-        print BLUE,"$ss$msg \n",RESET if($pr==4 and $color==1);
-        print RESET,"$ss$msg \n" if($pr==5 and $color==1);
+        print YELLOW,BOLD,"$msg \n",RESET if($pr==1 and $colour==1);
+        print YELLOW,"$ss$msg \n",RESET if($pr==2 and $colour==1);
+        print GREEN,"$ss$msg \n",RESET if($pr==3 and $colour==1);
+        print BLUE,"$ss$msg \n",RESET if($pr==4 and $colour==1);
+        print RESET,"$ss$msg \n" if($pr==5 and $colour==1);
       }
   }
 
